==> winston-json-formatter-0.9.0.tgz: package/lib/index.js <==
"use strict";

var _winston = _interopRequireDefault(require("winston"));

var _lodash = _interopRequireDefault(require("lodash"));

var _os = _interopRequireDefault(require("os"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  format
} = _winston.default;
const {
  printf,
  timestamp,
  combine,
  colorize
} = format;
const addMetaFormat = format((info, opts) => {
  const options = _lodash.default.defaults(opts, {
    name: 'application-logger',
    hostname: _os.default.hostname(),
    node_env: process.env.NODE_ENV,
    service: '',
    version: ''
  });

  return _lodash.default.defaults(info, options);
});
const consoleFormat = printf(info => `${info.timestamp} ${info.level}: ${info.message}`);
const jsonFormat = printf(info => {
  function parseInfo(infoObj) {
    return _lodash.default.omit(infoObj, ['err', 'hostname', 'level', 'logger', 'message', 'meta', 'name', 'node_env', 'service', 'stack', 'timestamp', 'typeFormat', 'version']);
  }

  return JSON.stringify({
    service: info.service || '',
    logger: info.name || 'application-logger',
    hostname: info.hostname || '',
    level: info.level,
    msg: info.message,
    meta: {
      service: {
        version: info.version || '',
        node_env: info.node_env || ''
      },
      logger: {
        time: info.timestamp || ''
      },
      event: parseInfo(info)
    },
    err: {
      err: info.err,
      message: info.message,
      name: info.name,
      stack: info.stack
    }
  });
});
/**
 * Configured formatter to check for env and key words (console and json)
 * @param {Object} options
 * @return {string} format
 */

function configuredFormatter(options = {}) {
  let {
    typeFormat
  } = options;

  if (typeFormat === undefined) {
    if (process.env.NODE_ENV === 'development' || process.env.NODE_ENV === 'dev') {
      typeFormat = 'console';
    } else {
      typeFormat = 'json';
    }
  }

  if (typeFormat === 'json') {
    return combine(timestamp(), addMetaFormat(options), jsonFormat);
  }

  if (typeFormat === 'console') {
    return combine(timestamp(), colorize(), consoleFormat);
  }

  throw new Error(`${typeFormat} is not json or console.`);
}

module.exports = {
  addMetaFormat,
  configuredFormatter,
  consoleFormat,
  jsonFormat
};

==> winston-json-formatter-0.9.2.tgz: package/lib/index.js <==
"use strict";

var _winston = _interopRequireDefault(require("winston"));

var _lodash = _interopRequireDefault(require("lodash"));

var _os = _interopRequireDefault(require("os"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  format
} = _winston.default;
const {
  printf,
  timestamp,
  combine,
  colorize
} = format;
const addMetaFormat = format((info, opts) => {
  const options = _lodash.default.defaults(opts, {
    hostname: _os.default.hostname(),
    logger: 'application-logger',
    node_env: process.env.NODE_ENV,
    service: '',
    version: ''
  });

  return _lodash.default.defaults(info, options);
});
const consoleFormat = printf(info => `${info.timestamp} ${info.level}: ${info.message}`);
const jsonFormat = printf(info => {
  function parseInfo(infoObj) {
    return _lodash.default.omit(infoObj, ['err', 'hostname', 'level', 'logger', 'message', 'meta', 'name', 'node_env', 'service', 'stack', 'timestamp', 'typeFormat', 'version']);
  }

  return JSON.stringify({
    service: info.service || '',
    logger: info.logger || 'application-logger',
    hostname: info.hostname || '',
    level: info.level,
    msg: info.message,
    meta: {
      service: {
        version: info.version || '',
        node_env: info.node_env || ''
      },
      logger: {
        time: info.timestamp || ''
      },
      event: parseInfo(info)
    },
    err: {
      name: info.name,
      stack: info.stack
    }
  });
});
/**
 * Configured formatter to check for env and key words (console and json)
 * @param {Object} options
 * @return {string} format
 */

function configuredFormatter(options = {}) {
  let {
    typeFormat
  } = options;

  if (typeFormat === undefined) {
    if (process.env.NODE_ENV === 'development' || process.env.NODE_ENV === 'dev') {
      typeFormat = 'console';
    } else {
      typeFormat = 'json';
    }
  }

  if (typeFormat === 'json') {
    return combine(timestamp(), addMetaFormat(options), jsonFormat);
  }

  if (typeFormat === 'console') {
    return combine(timestamp(), colorize(), consoleFormat);
  }

  throw new Error(`${typeFormat} is not json or console.`);
}

module.exports = {
  addMetaFormat,
  configuredFormatter,
  consoleFormat,
  jsonFormat
};
